meili_flutter library

Classes

AdditionalParams
AvailParams
Meili
MeiliConnectWidget
MeiliParams
Represents the parameters required to open the Meili view.

Enums

FlowType
Enum representing the different flow types for the MeiliView.